@@ -11,12 +11,12 @@ __all__ = [
     "__title__", "__uri__", "__version__",
 ]
 
-__version__ = "16.0.0"
+__version__ = "17.0.0"
 
 __title__ = "pyOpenSSL"
-__uri__ = "https://pyopenssl.readthedocs.org/"
+__uri__ = "https://pyopenssl.readthedocs.io/"
 __summary__ = "Python wrapper module around the OpenSSL library"
 __author__ = "The pyOpenSSL developers"
 __email__ = "cryptography-dev@python.org"
 __license__ = "Apache License, Version 2.0"
-__copyright__ = "Copyright 2001-2016 {0}".format(__author__)
+__copyright__ = "Copyright 2001-2017 {0}".format(__author__)
